import { defineComponent as A, ref as O, onMounted as N, watch as C, openBlock as I, createElementBlock as z } from "vue";
var M;
(function(s) {
  class o {
    /*-- Static factory functions (high level) --*/
    // Returns a QR Code representing the given Unicode text string at the given error correction level.
    // As a conservative upper bound, this function is guaranteed to succeed for strings that have 738 or fewer
    // Unicode code points (not UTF-16 code units) if the low error correction level is used. The smallest possible
    // QR Code version is automatically chosen for the output. The ECC level of the result may be higher than the
    // ecl argument if it can be done without increasing the version.
    static encodeText(e, r) {
      const t = s.QrSegment.makeSegments(e);
      return o.encodeSegments(t, r);
    }
    // Returns a QR Code representing the given binary data at the given error correction level.
    // This function always encodes using the binary segment mode, not any text mode. The maximum number of
    // bytes allowed is 2953. The smallest possible QR Code version is automatically chosen for the output.
    // The ECC level of the result may be higher than the ecl argument if it can be done without increasing the version.
    static encodeBinary(e, r) {
      const t = s.QrSegment.makeBytes(e);
      return o.encodeSegments([t], r);
    }
    /*-- Static factory functions (mid level) --*/
    // Returns a QR Code representing the given segments with the given encoding parameters.
    // The smallest possible QR Code version within the given range is automatically
    // chosen for the output. Iff boostEcl is true, then the ECC level of the result
    // may be higher than the ecl argument if it can be done without increasing the
    // version. The mask number is either between 0 to 7 (inclusive) to force that
    // mask, or -1 to automatically choose an appropriate mask (which may be slow).
    // This function allows the user to create a custom sequence of segments that switches
    // between modes (such as alphanumeric and byte) to encode text in less space.
    // This is a mid-level API; the high-level API is encodeText() and encodeBinary().
    static encodeSegments(e, r, t = 1, i = 40, n = -1, u = !0) {
      if (!(o.MIN_VERSION <= t && t <= i && i <= o.MAX_VERSION) || n < -1 || n > 7)
        throw new RangeError("Invalid value");
      let a, b;
      for (a = t; ; a++) {
        const m = o.getNumDataCodewords(a, r) * 8, g = c.getTotalBits(e, a);
        if (g <= m) {
          b = g;
          break;
        }
        if (a >= i)
          throw new RangeError("Data too long");
      }
      for (const m of [
        o.Ecc.MEDIUM,
        o.Ecc.QUARTILE,
        o.Ecc.HIGH
      ])
        u && b <= o.getNumDataCodewords(a, m) * 8 && (r = m);
      let h = [];
      for (const m of e) {
        l(m.mode.modeBits, 4, h), l(m.numChars, m.mode.numCharCountBits(a), h);
        for (const g of m.getData())
          h.push(g);
      }
      d(h.length == b);
      const P = o.getNumDataCodewords(a, r) * 8;
      d(h.length <= P), l(0, Math.min(4, P - h.length), h), l(0, (8 - h.length % 8) % 8, h), d(h.length % 8 == 0);
      for (let m = 236; h.length < P; m ^= 253)
        l(m, 8, h);
      let E = [];
      for (; E.length * 8 < h.length; )
        E.push(0);
      return h.forEach((m, g) => E[g >>> 3] |= m << 7 - (g & 7)), new o(a, r, E, n);
    }
    /*-- Constructor (low level) and fields --*/
    // Creates a new QR Code with the given version number,
    // error correction level, data codeword bytes, and mask number.
    // This is a low-level API that most users should not use directly.
    // A mid-level API is the encodeSegments() function.
    constructor(e, r, t, i) {
      if (Object.defineProperty(this, "version", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: e
      }), Object.defineProperty(this, "errorCorrectionLevel", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: r
      }), Object.defineProperty(this, "size", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: void 0
      }), Object.defineProperty(this, "mask", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: void 0
      }), Object.defineProperty(this, "modules", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: []
      }), Object.defineProperty(this, "isFunction", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: []
      }), e < o.MIN_VERSION || e > o.MAX_VERSION)
        throw new RangeError("Version value out of range");
      if (i < -1 || i > 7)
        throw new RangeError("Mask value out of range");
      this.size = e * 4 + 17;
      let n = [];
      for (let a = 0; a < this.size; a++)
        n.push(!1);
      for (let a = 0; a < this.size; a++)
        this.modules.push(n.slice()), this.isFunction.push(n.slice());
      this.drawFunctionPatterns();
      const u = this.addEccAndInterleave(t);
      if (this.drawCodewords(u), i == -1) {
        let a = 1e9;
        for (let b = 0; b < 8; b++) {
          this.applyMask(b), this.drawFormatBits(b);
          const h = this.getPenaltyScore();
          h < a && (i = b, a = h), this.applyMask(b);
        }
      }
      d(0 <= i && i <= 7), this.mask = i, this.applyMask(i), this.drawFormatBits(i), this.isFunction = [];
    }
    /*-- Accessor methods --*/
    // Returns the color of the module (pixel) at the given coordinates, which is false
    // for light or true for dark. The top left corner has the coordinates (x=0, y=0).
    // If the given coordinates are out of bounds, then false (light) is returned.
    getModule(e, r) {
      return 0 <= e && e < this.size && 0 <= r && r < this.size && this.modules[r][e];
    }
    /*-- Private helper methods for constructor: Drawing function modules --*/
    // Reads this object's version field, and draws and marks all function modules.
    drawFunctionPatterns() {
      for (let t = 0; t < this.size; t++)
        this.setFunctionModule(6, t, t % 2 == 0), this.setFunctionModule(t, 6, t % 2 == 0);
      this.drawFinderPattern(3, 3), this.drawFinderPattern(this.size - 4, 3), this.drawFinderPattern(3, this.size - 4);
      const e = this.getAlignmentPatternPositions(), r = e.length;
      for (let t = 0; t < r; t++)
        for (let i = 0; i < r; i++)
          t == 0 && i == 0 || t == 0 && i == r - 1 || t == r - 1 && i == 0 || this.drawAlignmentPattern(e[t], e[i]);
      this.drawFormatBits(0), this.drawVersion();
    }
    // Draws two copies of the format bits (with its own error correction code)
    // based on the given mask and this object's error correction level field.
    drawFormatBits(e) {
      const r = this.errorCorrectionLevel.formatBits << 3 | e;
      let t = r;
      for (let n = 0; n < 10; n++)
        t = t << 1 ^ (t >>> 9) * 1335;
      const i = (r << 10 | t) ^ 21522;
      d(i >>> 15 == 0);
      for (let n = 0; n <= 5; n++)
        this.setFunctionModule(8, n, f(i, n));
      this.setFunctionModule(8, 7, f(i, 6)), this.setFunctionModule(8, 8, f(i, 7)), this.setFunctionModule(7, 8, f(i, 8));
      for (let n = 9; n < 15; n++)
        this.setFunctionModule(14 - n, 8, f(i, n));
      for (let n = 0; n < 8; n++)
        this.setFunctionModule(this.size - 1 - n, 8, f(i, n));
      for (let n = 8; n < 15; n++)
        this.setFunctionModule(8, this.size - 15 + n, f(i, n));
      this.setFunctionModule(8, this.size - 8, !0);
    }
    // Draws two copies of the version bits (with its own error correction code),
    // based on this object's version field, iff 7 <= version <= 40.
    drawVersion() {
      if (this.version < 7)
        return;
      let e = this.version;
      for (let t = 0; t < 12; t++)
        e = e << 1 ^ (e >>> 11) * 7973;
      const r = this.version << 12 | e;
      d(r >>> 18 == 0);
      for (let t = 0; t < 18; t++) {
        const i = f(r, t), n = this.size - 11 + t % 3, u = Math.floor(t / 3);
        this.setFunctionModule(n, u, i), this.setFunctionModule(u, n, i);
      }
    }
    // Draws a 9*9 finder pattern including the border separator,
    // with the center module at (x, y). Modules can be out of bounds.
    drawFinderPattern(e, r) {
      for (let t = -4; t <= 4; t++)
        for (let i = -4; i <= 4; i++) {
          const n = Math.max(Math.abs(i), Math.abs(t)), u = e + i, a = r + t;
          0 <= u && u < this.size && 0 <= a && a < this.size && this.setFunctionModule(u, a, n != 2 && n != 4);
        }
    }
    // Draws a 5*5 alignment pattern, with the center module
    // at (x, y). All modules must be in bounds.
    drawAlignmentPattern(e, r) {
      for (let t = -2; t <= 2; t++)
        for (let i = -2; i <= 2; i++)
          this.setFunctionModule(e + i, r + t, Math.max(Math.abs(i), Math.abs(t)) != 1);
    }
    // Sets the color of a module and marks it as a function module.
    // Only used by the constructor. Coordinates must be in bounds.
    setFunctionModule(e, r, t) {
      this.modules[r][e] = t, this.isFunction[r][e] = !0;
    }
    /*-- Private helper methods for constructor: Codewords and masking --*/
    // Returns a new byte string representing the given data with the appropriate error correction
    // codewords appended to it, based on this object's version and error correction level.
    addEccAndInterleave(e) {
      const r = this.version, t = this.errorCorrectionLevel;
      if (e.length != o.getNumDataCodewords(r, t))
        throw new RangeError("Invalid argument");
      const i = o.NUM_ERROR_CORRECTION_BLOCKS[t.ordinal][r], n = o.ECC_CODEWORDS_PER_BLOCK[t.ordinal][r], u = Math.floor(o.getNumRawDataModules(r) / 8), a = i - u % i, b = Math.floor(u / i);
      let h = [];
      const P = o.reedSolomonComputeDivisor(n);
      for (let m = 0, g = 0; m < i; m++) {
        let p = e.slice(g, g + b - n + (m < a ? 0 : 1));
        g += p.length;
        const v = o.reedSolomonComputeRemainder(p, P);
        m < a && p.push(0), h.push(p.concat(v));
      }
      let E = [];
      for (let m = 0; m < h[0].length; m++)
        h.forEach((g, p) => {
          (m != b - n || p >= a) && E.push(g[m]);
        });
      return d(E.length == u), E;
    }
    // Draws the given sequence of 8-bit codewords (data and error correction) onto the entire
    // data area of this QR Code. Function modules need to be marked off before this is called.
    drawCodewords(e) {
      if (e.length != Math.floor(o.getNumRawDataModules(this.version) / 8))
        throw new RangeError("Invalid argument");
      let r = 0;
      for (let t = this.size - 1; t >= 1; t -= 2) {
        t == 6 && (t = 5);
        for (let i = 0; i < this.size; i++)
          for (let n = 0; n < 2; n++) {
            const u = t - n, b = (t + 1 & 2) == 0 ? this.size - 1 - i : i;
            !this.isFunction[b][u] && r < e.length * 8 && (this.modules[b][u] = f(e[r >>> 3], 7 - (r & 7)), r++);
          }
      }
      d(r == e.length * 8);
    }
    // XORs the codeword modules in this QR Code with the given mask pattern.
    // The function modules must be marked and the codeword bits must be drawn
    // before masking. Due to the arithmetic of XOR, calling applyMask() with
    // the same mask value a second time will undo the mask. A final well-formed
    // QR Code needs exactly one (not zero, two, etc.) mask applied.
    applyMask(e) {
      if (e < 0 || e > 7)
        throw new RangeError("Mask value out of range");
      for (let r = 0; r < this.size; r++)
        for (let t = 0; t < this.size; t++) {
          let i;
          switch (e) {
            case 0:
              i = (t + r) % 2 == 0;
              break;
            case 1:
              i = r % 2 == 0;
              break;
            case 2:
              i = t % 3 == 0;
              break;
            case 3:
              i = (t + r) % 3 == 0;
              break;
            case 4:
              i = (Math.floor(t / 3) + Math.floor(r / 2)) % 2 == 0;
              break;
            case 5:
              i = t * r % 2 + t * r % 3 == 0;
              break;
            case 6:
              i = (t * r % 2 + t * r % 3) % 2 == 0;
              break;
            case 7:
              i = ((t + r) % 2 + t * r % 3) % 2 == 0;
              break;
            default:
              throw new Error("Unreachable");
          }
          !this.isFunction[r][t] && i && (this.modules[r][t] = !this.modules[r][t]);
        }
    }
    // Calculates and returns the penalty score based on state of this QR Code's current modules.
    // This is used by the automatic mask choice algorithm to find the mask pattern that yields the lowest score.
    getPenaltyScore() {
      let e = 0;
      for (let n = 0; n < this.size; n++) {
        let u = !1, a = 0, b = [0, 0, 0, 0, 0, 0, 0];
        for (let h = 0; h < this.size; h++)
          this.modules[n][h] == u ? (a++, a == 5 ? e += o.PENALTY_N1 : a > 5 && e++) : (this.finderPenaltyAddHistory(a, b), u || (e += this.finderPenaltyCountPatterns(b) * o.PENALTY_N3), u = this.modules[n][h], a = 1);
        e += this.finderPenaltyTerminateAndCount(u, a, b) * o.PENALTY_N3;
      }
      for (let n = 0; n < this.size; n++) {
        let u = !1, a = 0, b = [0, 0, 0, 0, 0, 0, 0];
        for (let h = 0; h < this.size; h++)
          this.modules[h][n] == u ? (a++, a == 5 ? e += o.PENALTY_N1 : a > 5 && e++) : (this.finderPenaltyAddHistory(a, b), u || (e += this.finderPenaltyCountPatterns(b) * o.PENALTY_N3), u = this.modules[h][n], a = 1);
        e += this.finderPenaltyTerminateAndCount(u, a, b) * o.PENALTY_N3;
      }
      for (let n = 0; n < this.size - 1; n++)
        for (let u = 0; u < this.size - 1; u++) {
          const a = this.modules[n][u];
          a == this.modules[n][u + 1] && a == this.modules[n + 1][u] && a == this.modules[n + 1][u + 1] && (e += o.PENALTY_N2);
        }
      let r = 0;
      for (const n of this.modules)
        r = n.reduce((u, a) => u + (a ? 1 : 0), r);
      const t = this.size * this.size, i = Math.ceil(Math.abs(r * 20 - t * 10) / t) - 1;
      return d(0 <= i && i <= 9), e += i * o.PENALTY_N4, d(0 <= e && e <= 2568888), e;
    }
    /*-- Private helper functions --*/
    // Returns an ascending list of positions of alignment patterns for this version number.
    // Each position is in the range [0,177), and are used on both the x and y axes.
    // This could be implemented as lookup table of 40 variable-length lists of integers.
    getAlignmentPatternPositions() {
      if (this.version == 1)
        return [];
      {
        const e = Math.floor(this.version / 7) + 2, r = this.version == 32 ? 26 : Math.ceil((this.version * 4 + 4) / (e * 2 - 2)) * 2;
        let t = [6];
        for (let i = this.size - 7; t.length < e; i -= r)
          t.splice(1, 0, i);
        return t;
      }
    }
    // Returns the number of data bits that can be stored in a QR Code of the given version number, after
    // all function modules are excluded. This includes remainder bits, so it might not be a multiple of 8.
    // The result is in the range [208, 29648]. This could be implemented as a 40-entry lookup table.
    static getNumRawDataModules(e) {
      if (e < o.MIN_VERSION || e > o.MAX_VERSION)
        throw new RangeError("Version number out of range");
      let r = (16 * e + 128) * e + 64;
      if (e >= 2) {
        const t = Math.floor(e / 7) + 2;
        r -= (25 * t - 10) * t - 55, e >= 7 && (r -= 36);
      }
      return d(208 <= r && r <= 29648), r;
    }
    // Returns the number of 8-bit data (i.e. not error correction) codewords contained in any
    // QR Code of the given version number and error correction level, with remainder bits discarded.
    // This stateless pure function could be implemented as a (40*4)-cell lookup table.
    static getNumDataCodewords(e, r) {
      return Math.floor(o.getNumRawDataModules(e) / 8) - o.ECC_CODEWORDS_PER_BLOCK[r.ordinal][e] * o.NUM_ERROR_CORRECTION_BLOCKS[r.ordinal][e];
    }
    // Returns a Reed-Solomon ECC generator polynomial for the given degree. This could be
    // implemented as a lookup table over all possible parameter values, instead of as an algorithm.
    static reedSolomonComputeDivisor(e) {
      if (e < 1 || e > 255)
        throw new RangeError("Degree out of range");
      let r = [];
      for (let i = 0; i < e - 1; i++)
        r.push(0);
      r.push(1);
      let t = 1;
      for (let i = 0; i < e; i++) {
        for (let n = 0; n < r.length; n++)
          r[n] = o.reedSolomonMultiply(r[n], t), n + 1 < r.length && (r[n] ^= r[n + 1]);
        t = o.reedSolomonMultiply(t, 2);
      }
      return r;
    }
    // Returns the Reed-Solomon error correction codeword for the given data and divisor polynomials.
    static reedSolomonComputeRemainder(e, r) {
      let t = r.map((i) => 0);
      for (const i of e) {
        const n = i ^ t.shift();
        t.push(0), r.forEach((u, a) => t[a] ^= o.reedSolomonMultiply(u, n));
      }
      return t;
    }
    // Returns the product of the two given field elements modulo GF(2^8/0x11D). The arguments and result
    // are unsigned 8-bit integers. This could be implemented as a lookup table of 256*256 entries of uint8.
    static reedSolomonMultiply(e, r) {
      if (e >>> 8 || r >>> 8)
        throw new RangeError("Byte out of range");
      let t = 0;
      for (let i = 7; i >= 0; i--)
        t = t << 1 ^ (t >>> 7) * 285, t ^= (r >>> i & 1) * e;
      return d(t >>> 8 == 0), t;
    }
    // Can only be called immediately after a light run is added, and
    // returns either 0, 1, or 2. A helper function for getPenaltyScore().
    finderPenaltyCountPatterns(e) {
      const r = e[1];
      d(r <= this.size * 3);
      const t = r > 0 && e[2] == r && e[3] == r * 3 && e[4] == r && e[5] == r;
      return (t && e[0] >= r * 4 && e[6] >= r ? 1 : 0) + (t && e[6] >= r * 4 && e[0] >= r ? 1 : 0);
    }
    // Must be called at the end of a line (row or column) of modules. A helper function for getPenaltyScore().
    finderPenaltyTerminateAndCount(e, r, t) {
      return e && (this.finderPenaltyAddHistory(r, t), r = 0), r += this.size, this.finderPenaltyAddHistory(r, t), this.finderPenaltyCountPatterns(t);
    }
    // Pushes the given value to the front and drops the last value. A helper function for getPenaltyScore().
    finderPenaltyAddHistory(e, r) {
      r[0] == 0 && (e += this.size), r.pop(), r.unshift(e);
    }
  }
  Object.defineProperty(o, "MIN_VERSION", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: 1
  }), Object.defineProperty(o, "MAX_VERSION", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: 40
  }), Object.defineProperty(o, "PENALTY_N1", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: 3
  }), Object.defineProperty(o, "PENALTY_N2", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: 3
  }), Object.defineProperty(o, "PENALTY_N3", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: 40
  }), Object.defineProperty(o, "PENALTY_N4", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: 10
  }), Object.defineProperty(o, "ECC_CODEWORDS_PER_BLOCK", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: [
      // Version: (note that index 0 is for padding, and is set to an illegal value)
      //0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40    Error correction level
      [
        -1,
        7,
        10,
        15,
        20,
        26,
        18,
        20,
        24,
        30,
        18,
        20,
        24,
        26,
        30,
        22,
        24,
        28,
        30,
        28,
        28,
        28,
        28,
        30,
        30,
        26,
        28,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30
      ],
      // Low
      [
        -1,
        10,
        16,
        26,
        18,
        24,
        16,
        18,
        22,
        22,
        26,
        30,
        22,
        22,
        24,
        24,
        28,
        28,
        26,
        26,
        26,
        26,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28,
        28
      ],
      // Medium
      [
        -1,
        13,
        22,
        18,
        26,
        18,
        24,
        18,
        22,
        20,
        24,
        28,
        26,
        24,
        20,
        30,
        24,
        28,
        28,
        26,
        30,
        28,
        30,
        30,
        30,
        30,
        28,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30
      ],
      // Quartile
      [
        -1,
        17,
        28,
        22,
        16,
        22,
        28,
        26,
        26,
        24,
        28,
        24,
        28,
        22,
        24,
        24,
        30,
        28,
        28,
        26,
        28,
        30,
        24,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30,
        30
      ]
      // High
    ]
  }), Object.defineProperty(o, "NUM_ERROR_CORRECTION_BLOCKS", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: [
      // Version: (note that index 0 is for padding, and is set to an illegal value)
      //0, 1, 2, 3, 4, 5, 6, 7, 8, 9,10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40    Error correction level
      [
        -1,
        1,
        1,
        1,
        1,
        1,
        2,
        2,
        2,
        2,
        4,
        4,
        4,
        4,
        4,
        6,
        6,
        6,
        6,
        7,
        8,
        8,
        9,
        9,
        10,
        12,
        12,
        12,
        13,
        14,
        15,
        16,
        17,
        18,
        19,
        19,
        20,
        21,
        22,
        24,
        25
      ],
      // Low
      [
        -1,
        1,
        1,
        1,
        2,
        2,
        4,
        4,
        4,
        5,
        5,
        5,
        8,
        9,
        9,
        10,
        10,
        11,
        13,
        14,
        16,
        17,
        17,
        18,
        20,
        21,
        23,
        25,
        26,
        28,
        29,
        31,
        33,
        35,
        37,
        38,
        40,
        43,
        45,
        47,
        49
      ],
      // Medium
      [
        -1,
        1,
        1,
        2,
        2,
        4,
        4,
        6,
        6,
        8,
        8,
        8,
        10,
        12,
        16,
        12,
        17,
        16,
        18,
        21,
        20,
        23,
        23,
        25,
        27,
        29,
        34,
        34,
        35,
        38,
        40,
        43,
        45,
        48,
        51,
        53,
        56,
        59,
        62,
        65,
        68
      ],
      // Quartile
      [
        -1,
        1,
        1,
        2,
        4,
        4,
        4,
        5,
        6,
        8,
        8,
        11,
        11,
        16,
        16,
        18,
        16,
        19,
        21,
        25,
        25,
        25,
        34,
        30,
        32,
        35,
        37,
        40,
        42,
        45,
        48,
        51,
        54,
        57,
        60,
        63,
        66,
        70,
        74,
        77,
        81
      ]
      // High
    ]
  }), s.QrCode = o;
  function l(w, e, r) {
    if (e < 0 || e > 31 || w >>> e)
      throw new RangeError("Value out of range");
    for (let t = e - 1; t >= 0; t--)
      r.push(w >>> t & 1);
  }
  function f(w, e) {
    return (w >>> e & 1) != 0;
  }
  function d(w) {
    if (!w)
      throw new Error("Assertion error");
  }
  class c {
    /*-- Static factory functions (mid level) --*/
    // Returns a segment representing the given binary data encoded in
    // byte mode. All input byte arrays are acceptable. Any text string
    // can be converted to UTF-8 bytes and encoded as a byte mode segment.
    static makeBytes(e) {
      let r = [];
      for (const t of e)
        l(t, 8, r);
      return new c(c.Mode.BYTE, e.length, r);
    }
    // Returns a segment representing the given string of decimal digits encoded in numeric mode.
    static makeNumeric(e) {
      if (!c.isNumeric(e))
        throw new RangeError("String contains non-numeric characters");
      let r = [];
      for (let t = 0; t < e.length; ) {
        const i = Math.min(e.length - t, 3);
        l(parseInt(e.substring(t, t + i), 10), i * 3 + 1, r), t += i;
      }
      return new c(c.Mode.NUMERIC, e.length, r);
    }
    // Returns a segment representing the given text string encoded in alphanumeric mode.
    // The characters allowed are: 0 to 9, A to Z (uppercase only), space,
    // dollar, percent, asterisk, plus, hyphen, period, slash, colon.
    static makeAlphanumeric(e) {
      if (!c.isAlphanumeric(e))
        throw new RangeError("String contains unencodable characters in alphanumeric mode");
      let r = [], t;
      for (t = 0; t + 2 <= e.length; t += 2) {
        let i = c.ALPHANUMERIC_CHARSET.indexOf(e.charAt(t)) * 45;
        i += c.ALPHANUMERIC_CHARSET.indexOf(e.charAt(t + 1)), l(i, 11, r);
      }
      return t < e.length && l(c.ALPHANUMERIC_CHARSET.indexOf(e.charAt(t)), 6, r), new c(c.Mode.ALPHANUMERIC, e.length, r);
    }
    // Returns a new mutable list of zero or more segments to represent the given Unicode text string.
    // The result may use various segment modes and switch modes to optimize the length of the bit stream.
    static makeSegments(e) {
      return e == "" ? [] : c.isNumeric(e) ? [c.makeNumeric(e)] : c.isAlphanumeric(e) ? [c.makeAlphanumeric(e)] : [c.makeBytes(c.toUtf8ByteArray(e))];
    }
    // Returns a segment representing an Extended Channel Interpretation
    // (ECI) designator with the given assignment value.
    static makeEci(e) {
      let r = [];
      if (e < 0)
        throw new RangeError("ECI assignment value out of range");
      if (e < 128)
        l(e, 8, r);
      else if (e < 16384)
        l(2, 2, r), l(e, 14, r);
      else if (e < 1e6)
        l(6, 3, r), l(e, 21, r);
      else
        throw new RangeError("ECI assignment value out of range");
      return new c(c.Mode.ECI, 0, r);
    }
    // Tests whether the given string can be encoded as a segment in numeric mode.
    // A string is encodable iff each character is in the range 0 to 9.
    static isNumeric(e) {
      return c.NUMERIC_REGEX.test(e);
    }
    // Tests whether the given string can be encoded as a segment in alphanumeric mode.
    // A string is encodable iff each character is in the following set: 0 to 9, A to Z
    // (uppercase only), space, dollar, percent, asterisk, plus, hyphen, period, slash, colon.
    static isAlphanumeric(e) {
      return c.ALPHANUMERIC_REGEX.test(e);
    }
    /*-- Constructor (low level) and fields --*/
    // Creates a new QR Code segment with the given attributes and data.
    // The character count (numChars) must agree with the mode and the bit buffer length,
    // but the constraint isn't checked. The given bit buffer is cloned and stored.
    constructor(e, r, t) {
      if (Object.defineProperty(this, "mode", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: e
      }), Object.defineProperty(this, "numChars", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: r
      }), Object.defineProperty(this, "bitData", {
        enumerable: !0,
        configurable: !0,
        writable: !0,
        value: t
      }), r < 0)
        throw new RangeError("Invalid argument");
      this.bitData = t.slice();
    }
    /*-- Methods --*/
    // Returns a new copy of the data bits of this segment.
    getData() {
      return this.bitData.slice();
    }
    // (Package-private) Calculates and returns the number of bits needed to encode the given segments at
    // the given version. The result is infinity if a segment has too many characters to fit its length field.
    static getTotalBits(e, r) {
      let t = 0;
      for (const i of e) {
        const n = i.mode.numCharCountBits(r);
        if (i.numChars >= 1 << n)
          return 1 / 0;
        t += 4 + n + i.bitData.length;
      }
      return t;
    }
    // Returns a new array of bytes representing the given string encoded in UTF-8.
    static toUtf8ByteArray(e) {
      e = encodeURI(e);
      let r = [];
      for (let t = 0; t < e.length; t++)
        e.charAt(t) != "%" ? r.push(e.charCodeAt(t)) : (r.push(parseInt(e.substring(t + 1, t + 3), 16)), t += 2);
      return r;
    }
  }
  Object.defineProperty(c, "NUMERIC_REGEX", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: /^[0-9]*$/
  }), Object.defineProperty(c, "ALPHANUMERIC_REGEX", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: /^[A-Z0-9 $%*+.\/:-]*$/
  }), Object.defineProperty(c, "ALPHANUMERIC_CHARSET", {
    enumerable: !0,
    configurable: !0,
    writable: !0,
    value: "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ $%*+-./:"
  }), s.QrSegment = c;
})(M || (M = {}));
(function(s) {
  (function(o) {
    class l {
      /*-- Constructor and fields --*/
      constructor(d, c) {
        Object.defineProperty(this, "ordinal", {
          enumerable: !0,
          configurable: !0,
          writable: !0,
          value: d
        }), Object.defineProperty(this, "formatBits", {
          enumerable: !0,
          configurable: !0,
          writable: !0,
          value: c
        });
      }
    }
    Object.defineProperty(l, "LOW", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(0, 1)
    }), Object.defineProperty(l, "MEDIUM", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(1, 0)
    }), Object.defineProperty(l, "QUARTILE", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(2, 3)
    }), Object.defineProperty(l, "HIGH", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(3, 2)
    }), o.Ecc = l;
  })(s.QrCode || (s.QrCode = {}));
})(M || (M = {}));
(function(s) {
  (function(o) {
    class l {
      /*-- Constructor and fields --*/
      constructor(d, c) {
        Object.defineProperty(this, "modeBits", {
          enumerable: !0,
          configurable: !0,
          writable: !0,
          value: d
        }), Object.defineProperty(this, "numBitsCharCount", {
          enumerable: !0,
          configurable: !0,
          writable: !0,
          value: c
        });
      }
      /*-- Method --*/
      // (Package-private) Returns the bit width of the character count field for a segment in
      // this mode in a QR Code at the given version number. The result is in the range [0, 16].
      numCharCountBits(d) {
        return this.numBitsCharCount[Math.floor((d + 7) / 17)];
      }
    }
    Object.defineProperty(l, "NUMERIC", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(1, [10, 12, 14])
    }), Object.defineProperty(l, "ALPHANUMERIC", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(2, [9, 11, 13])
    }), Object.defineProperty(l, "BYTE", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(4, [8, 16, 16])
    }), Object.defineProperty(l, "KANJI", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(8, [8, 10, 12])
    }), Object.defineProperty(l, "ECI", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: new l(7, [0, 0, 0])
    }), o.Mode = l;
  })(s.QrSegment || (s.QrSegment = {}));
})(M || (M = {}));
const y = M;
function B(s) {
  return {
    size: 100,
    level: "M",
    el: null,
    text: null,
    fill: "#000000",
    background: "#ffffff",
    icon: void 0,
    ...s
  };
}
function j(s) {
  return {
    size: 40,
    // biome-ignore lint: reason
    image: null,
    ...s
  };
}
function R(s, o) {
  let l = y.QrCode.Ecc.LOW;
  return o === "M" ? l = y.QrCode.Ecc.MEDIUM : o === "Q" ? l = y.QrCode.Ecc.QUARTILE : o === "H" && (l = y.QrCode.Ecc.HIGH), y.QrCode.encodeText(s, l);
}
function D(s, o = "table", l = null) {
  if (s == null ? l == null ? s = document.createElement(o) : s = document.createElementNS(l, o) : typeof s == "string" && (s = document.querySelector(s)), s == null)
    throw new Error("el error");
  if (s.tagName.toUpperCase() !== o.toUpperCase())
    throw new Error("output and tag are mismatch");
  return s;
}
function F(s, o) {
  if (s.icon != null) {
    const l = new Image();
    l.src = s.icon.src, l.onload = () => {
      s.icon.image = l, o(s);
    }, l.onerror = () => {
      o(s);
    };
  } else
    o(s);
}
function L(s, o) {
  const l = D(o.el, "canvas");
  return F(o, (f) => {
    const d = f.size / s.size;
    l.width = f.size, l.height = f.size;
    const c = l.getContext("2d");
    c.clearRect(0, 0, l.width, l.height);
    for (let w = 0; w < s.size; w++)
      for (let e = 0; e < s.size; e++) {
        c.fillStyle = s.getModule(e, w) ? f.fill : f.background;
        const r = Math.floor(e * d), t = Math.ceil(d), i = Math.floor(w * d);
        c.fillRect(r, i, t, t);
      }
    if (f.icon != null && f.icon.image != null) {
      const w = j(f.icon), e = Math.floor(Math.min(w.size, f.size * 0.3)), r = f.size / 2 - e / 2;
      c.drawImage(f.icon.image, r, r, e, e);
    }
  }), l;
}
class T {
  constructor(o) {
    Object.defineProperty(this, "option", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: void 0
    }), Object.defineProperty(this, "qrcode", {
      enumerable: !0,
      configurable: !0,
      writable: !0,
      value: void 0
    });
    const l = B(o);
    this.option = l, this.qrcode = R(l.text || "", l.level);
  }
  /** 渲染二维码 */
  render() {
    return this.option.renderFn(this.qrcode, this.option);
  }
  /** 添加数据并渲染二维码 */
  addData(o) {
    let l = this.option.text || "";
    return l = `${l}${o}`, this.resetData(l);
  }
  /** 重置二维码 */
  resetData(o) {
    return this.option.text = o, this.qrcode = R(o, this.option.level), this.render();
  }
}
const U = /* @__PURE__ */ A({
  __name: "Qrcode",
  props: {
    text: {},
    size: { default: 100 },
    fill: { default: "#000000" },
    level: { default: "M" },
    iconSrc: { default: void 0 }
  },
  setup(s) {
    const o = O();
    let l;
    const f = s;
    return N(() => {
      l = new T({
        size: f.size,
        fill: f.fill,
        level: f.level,
        renderFn: L,
        text: f.text,
        el: o.value,
        icon: f.iconSrc ? {
          src: f.iconSrc
        } : void 0
      }), f.text != null && l.render();
    }), C(
      () => f.text,
      (d) => {
        d != null && l.resetData(d);
      }
    ), (d, c) => (I(), z("canvas", {
      ref_key: "$canvas",
      ref: o,
      width: "100",
      height: "100"
    }, null, 512));
  }
});
export {
  U as _
};
